#
# spec file for package kwayland
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _tar_path 5.26
Name:           kwayland
Version:        5.26.0
Release:        1.2
Summary:        KDE Wayland library
License:        LGPL-2.1+
Group:          Development/Libraries/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE fix-wayland-1.3-dependency.diff alarrosa@suse.de -- Changes the wayland version kwayland depends on
Patch0:         fix-wayland-1.3-dependency.diff
BuildRequires:  cmake >= 2.8.12
BuildRequires:  extra-cmake-modules >= %{_tar_path}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libQt5Gui-private-headers-devel >= 5.5.0
# cmake(Qt5Concurrent) is not enabled as it is used for a not installed tool, and only built when BUILD_TESTING=ON
#BuildRequires:  cmake(Qt5Concurrent) >= 5.5.0
BuildRequires:  cmake(Qt5Gui) >= 5.5.0
BuildRequires:  cmake(Qt5Test) >= 5.5.0
BuildRequires:  pkgconfig(egl)
%if 0%{?suse_version} == 1315 && ! 0%{?is_opensuse}
# We have a patched wayland 1.2.1 version in SLE12 with the required features from 1.7.0
BuildRequires:  pkgconfig(wayland-client) >= 1.2.1
BuildRequires:  pkgconfig(wayland-server) >= 1.2.1
%else
BuildRequires:  pkgconfig(wayland-client) >= 1.7.0
BuildRequires:  pkgconfig(wayland-server) >= 1.7.0
%endif
Provides:       libKF5WaylandClient5 = %{version}
Obsoletes:      libKF5WaylandClient5 <= %{version}
Provides:       libKF5WaylandServer5 = %{version}
Obsoletes:      libKF5WaylandServer5 <= %{version}
%requires_eq libQt5Gui5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%package devel
Summary:        KDE Wayland library: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules >= 1.2.0
Requires:       cmake(Qt5Gui) >= 5.5.0

%description devel
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%prep
%setup -q
%if 0%{?suse_version} == 1315 && ! 0%{?is_opensuse}
%patch0 -p1
%endif

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING*
%config %{_kf5_configdir}/org_kde_kwayland.categories
%{_kf5_libdir}/libKF5WaylandClient.so.*
%{_kf5_libdir}/libKF5WaylandServer.so.*

%files devel
%defattr(-,root,root)
%{_kf5_libdir}/libKF5WaylandClient.so
%{_kf5_libdir}/libKF5WaylandServer.so
%{_kf5_libdir}/libexec/org-kde-kf5-kwayland-testserver
%{_kf5_libdir}/cmake/KF5Wayland/
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_KWaylandClient.pri
%{_kf5_mkspecsdir}/qt_KWaylandServer.pri

%changelog
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Make linux/input.h compile time optional
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Wed Aug 10 2016 alarrosa@suse.com
- Rebase fix-wayland-1.3-dependency.diff
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * [client] Use a QPointer for the enteredSurface in Pointer
  * Expose Geometry in PlasmaWindowModel
  * Add a geometry event to PlasmaWindow
  * [src/server] Verify that surface has a resource before sending pointer enter
  * Add support for xdg-shell
  * [server] Properly send a selection clear prior to keyboard focus enter
  * [server] Handle no XDG_RUNTIME_DIR situation more gracefully
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Add a parent_window event to Plasma Window interface
  * Properly handle destroying a Pointer/Keyboard/Touch resource
  * [server] Delete dead code: KeyboardInterface::Private::sendKeymap
  * [server] Add support for setting the clipboard selection
    DataDeviceInterface manually
  * [server] Ensure that Resource::Private::get returns nullptr
    if passed a nullptr
  * [server] Add resource check in QtExtendedSurfaceInterface::close
  * [server] Unset SurfaceInterface pointer in referenced objects
    when being destroyed
  * [server] Fix error message in QtSurfaceExtension Interface
  * [server] Introduce a Resource::unbound signal emitted from
    unbind handler
  * [server] Don't assert when destroying a still
    referenced BufferInterface
  * Add destructor request to org_kde_kwin_shadow and
    org_kde_kwin_shadow_manager
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * [client] Don't check resource version for PlasmaWindow
  * Introduce an initial state event into Plasma Window protocol
  * [server] Trigger error if a transient request tries to parent
    to itself
  * [server] Properly handle the case that a PlasmaWindow is unmapped
    before client bound it
  * [server] Properly handle destructor in SlideInterface
  * Add support for touch events in fakeinput protocol and interface
  * [server] Standardize the destructor request handling for Resources
  * Implement wl_text_input and zwp_text_input_v2 interfaces
  * [server] Prevent double delete of callback resources
    in SurfaceInterface
  * [server] Add resource nullptr check to ShellSurfaceInterface
  * [server] Compare ClientConnection instead of wl_client
    in SeatInterface
  * [server] Improve the handling when clients disconnect
  * server/plasmawindowmanagement_interface.cpp - fix -Wreorder warning
  * [client] Add context pointer to connects in PlasmaWindowModel
  * Many fixes related to destruction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * KWayland is now part of KDE Frameworks
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Wed Dec 23 2015 alarrosa@suse.com
- Add fix-wayland-1.3-dependency.diff again, rebased to apply correctly
  now that there are wayland packages for SLE12 updated with the new
  requirements from wayland 1.7
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
- Drop no longer applicable fix-wayland-1.3-dependency.diff
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Thu Oct 29 2015 alarrosa@suse.com
- Added fix-wayland-1.3-dependency.diff -> changed requirements for
  SLE12, where an older wayland version has been patched to support
  the required features from wayland 1.3.0 needed by kwayland
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
- Merge the two shlib packages into one main one
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Added pkgconfig(egl) BuildRequires
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Drop 0001-Do-not-find-unused-Wayland-components.patch, upstreamed
- Build the server shlib
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Mon Nov  3 2014 hrvoje.senjan@gmail.com
- Added 0001-Do-not-find-unused-Wayland-components.patch to drop
  not needed BuildRequires, pkgconfig(wayland-egl)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API improvements since last update
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Activate KWayland package - KDE bindings for Wayland protocol and
  library
